@@ -1,13 +1,12 @@
 #!/usr/bin/env python
 #coding:utf-8
-# Author:  Manfred Moitzi
-# Purpose: test dxfwrite.util functions
 # Created: 08.12.2011
 # Copyright (C) 2011, Manfred Moitzi
 # License: GPLv3
 
+__author__ = "mozman <mozman@gmx.at>"
+
 import unittest
-import sys
 
 from dxfwrite.util import to_string, to_unicode
 
